Some grants columns are lists as they may have multiple entries. This will collapse them with semicolons between each entry. Note that this will be SLOW on a large grants data.frame.

flatten_list_columns(grants)

Arguments

grants

A data.frame of grant info

Value

A data.frame of grant info where each column is a "normal" vector: character, numeric, etc.