Since the returns are limited to 3,000 entries total, we will search by state, then aggregate. Progress as you go will be saved to save_file. You can also specify a startdate; this is mostly used internally for updating the cache.

nsf_get_all(save_file = "NSFAllGrants.rda", startdate = NULL)

Arguments

save_file

File to save results to while running

startdate

Start date for award date to search. Accepted date format is mm/dd/yyyy (ex.12/31/2012)

Value

A data frame with grant info

Details

There are over 500,000 NSF grants. This will take hours to run and result in a file almost a gigabyte in size.