Adds grants, pulling all the ones from this year, and uses piggyback to store the info.

nsf_update_cached_this_year(override_shrinkage = FALSE)

Arguments

override_shrinkage

By default, if an update results in fewer grants, it will stop with an error (we don't want to overwrite the cache if there was a failure to load grants). If TRUE, it will add grants anyway.

Value

A data.frame with the original grants data from this year and appended new data

Examples

# not running as it's slow
# grants <- nsf_update_cached_this_year()