This will save a CSV of all grants by decade (to make it easier to get the relevant files)

save_grant_csvs(grants, path)

Arguments

grants

A data.frame of grant info

path

Where to save the files

Value

Nothing, but the files will appear in the correct directory