nsf_update_cached.RdAdds grants after the last cached ones. However, it seemed to only add 60 grants in total; use nsf_update_cached_this_year() instead, or nsf_get_all() to get a new pull of every grant (takes days)
nsf_update_cached()A data.frame with the original grants data and appended new data
# not running as it's slow
# grants <- nsf_update_cached()
# usethis::use_data(grants, overwrite=TRUE) # if you are updating the package as well