nsf_update_cached_this_year.RdAdds grants, pulling all the ones from this year.
nsf_update_cached_this_year()A data.frame with the original grants data and appended new data
# not running as it's slow
# grants <- nsf_update_cached_this_year()
# usethis::use_data(grants, overwrite=TRUE) # if you are updating the package as well