nsf_update_this_year.Rd
Adds grants, pulling all the ones from this year.
nsf_update_this_year(grants)
A data.frame with the original grants data and appended new data
# not running as it's slow # grants <- nsf_update_this_year(grants)