nsf_wordcloud.RdCreate a wordcloud of text. This excludes common English words ("the", "and") but you can add your own to exclude as well. This uses the wordcloud package for plotting, and you can pass other arguments to that to make the plot prettier (see ?wordcloud::wordcloud) This follows the advice from http://www.sthda.com/english/wiki/text-mining-and-word-cloud-fundamentals-in-r-5-simple-steps-you-should-know on making a word cloud
nsf_wordcloud(
text = nsf_get_all()$abstractText,
prune_words = c("will", "nfs"),
max_words = 500,
...
)Make a word cloud of all the interesting words
data(grants)
nsf_wordcloud(grants$abstractText[1:10])