save_grant_csvs.Rd
This will save a CSV of all grants by decade (to make it easier to get the relevant files)
save_grant_csvs(grants, path)
A data.frame of grant info
Where to save the files
Nothing, but the files will appear in the correct directory